import os
import logging
from kubernetes import config 

__author__ = """Marco Masetti"""
__email__ = 'marco.masetti@sky.uk'
__version__ = '0.3.6'

log = logging.getLogger(__name__)

if os.getenv('KUBERNETES_SERVICE_HOST'):
    try:
        print("Connecting using incluster config...")
        log.debug("Connecting using incluster config...")
        config.load_incluster_config()
        log.debug("Connected...")
    except Exception as e:
        print("Error connecting to local k8s cluster: {}".format(e))
        log.error("Error connecting to local k8s cluster: {}".format(e))
else:
    try:
        print("Connecting via kube config file...")
        log.debug("Connecting via kube config file...")
        config.load_kube_config()
        log.debug("Connected...")
    except Exception as e:
        print("Error connecting to k8s: {}".format(e))
        log.error("Error connecting to k8s: {}".format(e))
 
