import logging
from kubernetes import client, config, utils
from uuid import uuid1


class Job:


    def __init__(self, context, namespace='default'):
        if context:
            config.load_kube_config(context=context)
        self.client_obj = client.api_client.ApiClient()
        self.batch_v1 = client.BatchV1Api()
        self.logger = logging.getLogger(__name__)
        self.namespace = namespace


    def create_job(self, 
            image, 
            command,
            name,
            service_account:str=None
            ) -> str:


        try:
            id = name + '-' + str(uuid1())[:8]
            job = {
                "apiVersion": "batch/v1",
                "kind": "Job",
                "metadata": {
                    "name": id,
                    "namespace": self.namespace,
                },
                "spec": {
                    "backoffLimit":3,
                    "template": {
                        "metadata": {
                            "labels": {
                                "app": name
                            },
                            "namespace": self.namespace
                        },
                        "spec": {
                            "containers": [
                                {
                                    "name": id,
                                    "image": image,
                                    "image_pull_policy":"Always",
                                    "command":command,
                                    "resources": {
                                        "limits": {"memory": "999Mi"}, 
                                        "requests": {"memory": "999Mi"}
                                    }
                                }
                            ],
                            "restartPolicy": "Never",
                            "serviceAccountName": service_account,
                            "terminationGracePeriodSeconds": 30
                       }
                    }
                }
            }

            utils.create_from_dict(
                    self.client_obj,
                    job,
                    verbose=True,
                    namespace=self.namespace
            )
            return id

        except utils.FailToCreateError as err:
            self.logger.error("Error creating resource {}: {}".format(name, err))
            return None


    def get_jobs(self):
        jobs = self.batch_v1.list_namespaced_job(
            namespace=self.namespace,pretty=True).items
        return [vars(i) for i in jobs]


    def __getitem__(self, pos):
        return self.get_jobs()[pos]

    def __len__(self):
        return len(self.get_jobs())
