import datetime
import logging
import json
import re
from kubernetes import client, config
from uuid import uuid1

# Note: apis readme: kubernetes-client/python/kubernetes/docs/CoreV1Api.md



class Cronk8s:
    def __init__(self, namespace='default'):
        config.load_kube_config()
        self.v1 = client.CoreV1Api()
        self.ExtV1beta1Api = client.ExtensionsV1beta1Api()
        self.BatchV1Beta = client.BatchV1beta1Api()
        self.data = client.V1beta1CronJob()
        self.logger = logging.getLogger(__name__)
        self.namespace = namespace

    def create_cronjob(
            self,
            filename, 
            schedule,
            image, 
            p2_store_endpoint, 
            service_account=None
            ):
        if p2_store_endpoint[-1] != '/':
            p2_store_endpoint += '/'
        try:
            import pdb;pdb.set_trace()
            namespace = self.namespace
            cronjob_name = filename+'-'+str(uuid1())[:8]

            self.data.kind = 'CronJob'
            meta = client.V1ObjectMeta()
            meta.name = cronjob_name,
            meta.namespace = namespace,
            meta.labels = {'app': filename}
            self.data.metadata = meta
            pod_template = client.V1PodSpec(
                containers=[client.V1Container(
                    name   = filename,
                    image  = image,
                    image_pull_policy='Always',
                    command=["./run-exp.py", p2_store_endpoint + "experiment/" + filename, schedule],
                    resources={"limits": {"memory": "999Mi"}, "requests": {"memory": "999Mi"}}
                    )],
                restart_policy="Never",
                service_account_name=service_account,
                )
            spec_pod_template = client.V1PodTemplate()
            job_template = client.V1beta1JobTemplateSpec()
            job_template.spec=spec_pod_template
            spec_pod_template.template= {}
            spec_pod_template.template['spec']=pod_template
            cron_job_spec = client.V1beta1CronJobSpec(
                    schedule="*/1 * * * *", 
                    job_template=job_template
                    )
            self.data.spec=cron_job_spec
            cronjob = self.BatchV1Beta.create_namespaced_cron_job(
                    body=self.data, 
                    namespace=namespace
                    )
            return cronjob            
        except Exception as err:
            self.logger.error("Error creating cronjob: {}".format(err))



if __name__ == "__main__":
    obj = Cronk8s(namespace='default')
    obj.create_cronjob(
            filename            = 'test-cron-1', 
            schedule            = '0 * * * *',
            image               = 'busybox', 
            p2_store_endpoint   = 'http://localhost:5000/store'
            )


