#!/usr/bin/env python
import os
from setuptools import setup, find_namespace_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

setup_requirements = ['pytest-runner', ]
test_requirements = ['pytest>=3', ]

def get_version_from_package() -> str:
    path = os.path.join(os.path.dirname(__file__), "p2/driver/k8s/__init__.py")
    path = os.path.normpath(os.path.abspath(path))
    with open(path) as f:
        for line in f:
            if line.startswith("__version__"):
                token, version = line.split(" = ", 1)
                version = version.replace("'", "").strip()
                return version



setup(
    author="Marco Masetti",
    author_email='marco.masetti@sky.uk',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="P2 driver for K8s",
    license="BSD license",
    long_description=readme,
    include_package_data=True,
    keywords='p2,driver,k8s',
    name='p2.driver.k8s',
    packages=find_namespace_packages(),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/sky-uk/p2.driver.k8s',
    version=get_version_from_package(),
    zip_safe=False,
)
