#!/usr/bin/env python
import pytest
import logging
import os
import time
from uuid import uuid1
from pprint import pprint

from p2.driver.k8s import k8s

log = logging.getLogger(__name__)

@pytest.fixture
def config():

    api_obj = k8s.Api(context='minikube')
    cron_obj = k8s.Cron(context='minikube')

    return {
            'image':                'hello-world',
            'namespace':            'default',
    }


def test_01_delete_all_cronjobs(config):
    k8s_obj = k8s.Cron(context='minikube')

    cronjob_name = 'test-exp'+'-'+str(uuid1())[:8]
    cronjob = k8s_obj.create_cronjob(
            name=cronjob_name,
            image = config['image'],
            command = ["./say-hello"],
            filename='test-exp', 
            schedule='0 * * * *'
            ) 
    assert cronjob != None

    deleted = k8s_obj.delete_all_cronjobs()
    assert cronjob in deleted

def test_02_create_cronjob(config):

    k8s_obj = k8s.Cron(context='minikube')
    k8s_obj.delete_all_cronjobs()
    time.sleep(10)
    cronjob_name = 'test-exp'+'-'+str(uuid1())[:8]
    cronjob = k8s_obj.create_cronjob(
            name=cronjob_name,
            image = config['image'],
            command = ["./say-hello"],
            filename='test-exp', 
            schedule='0 * * * *'
            ) 
    assert cronjob != None

    time.sleep(1)
    crons = k8s_obj.get_cronjobs()
    assert len(crons) > 0
    pprint(crons)

def test_03_get_cronjobs(config):
    k8s_obj = k8s.Cron(context='minikube')
    cronjobs = k8s_obj.get_cronjobs()
    assert len(cronjobs) > 0
