#!/usr/bin/env python
import pytest
import logging
import os

from p2.driver.k8s import k8s

log = logging.getLogger(__name__)


@pytest.fixture
def config():

    api_obj = k8s.Api(context='minikube')

def test_api_no_context():
    api = k8s.Api()
    ns = api.namespaces()
    assert len(ns) > 0

def test_namespaces(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0

def test_deployments_for_namespace(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0
    name = 'kube-system'
    print("Getting deployments for namespace " + name)
    d = api.deployments_for_namespace(name)
    assert len(d.keys()) >= 0
    for dep in d.keys():
        assert d[dep]['DESIRED_REPLICAS'] == 2
        assert api.is_deployment_healthy(d[dep]) is True

def test_is_deployment_healthy(config):
    api = k8s.Api(context='minikube')
    deployment={"DESIRED_REPLICAS": 2, "name": "k8-account-data-checker", "namespace": "acdc-int-nft", "labels": {"app": "k8-account-data-checker", "deployment": "k8-account-data-checker", "team": "njp"}, "status": {"available_replicas": 2, "ready_replicas": 2, "replicas": 2, "updated_replicas": 2}}
    assert api.is_deployment_healthy(deployment) is True


def test_pods_in_namespace(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0
    name = ns[0]["name"]
    pods = api.pods_in_namespace(name)
    assert len(pods) >= 0
